@@ -1,7 +1,7 @@
 """
 Type annotations for amplifybackend service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/type_defs/)
 
 Usage::
 
@@ -14,8 +14,6 @@ Usage::
 import sys
 from typing import Any, Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AdditionalConstraintsElementType,
     AuthenticatedElementType,
@@ -107,6 +105,7 @@ __all__ = (
     "ImportBackendAuthResponseTypeDef",
     "ImportBackendStorageRequestRequestTypeDef",
     "ImportBackendStorageResponseTypeDef",
+    "ListBackendJobsRequestListBackendJobsPaginateTypeDef",
     "ListBackendJobsRequestRequestTypeDef",
     "ListBackendJobsResponseTypeDef",
     "ListS3BucketsRequestRequestTypeDef",
@@ -146,83 +145,115 @@ __all__ = (
 BackendAPIAppSyncAuthSettingsTypeDef = TypedDict(
     "BackendAPIAppSyncAuthSettingsTypeDef",
     {
-        "CognitoUserPoolId": NotRequired[str],
-        "Description": NotRequired[str],
-        "ExpirationTime": NotRequired[float],
-        "OpenIDAuthTTL": NotRequired[str],
-        "OpenIDClientId": NotRequired[str],
-        "OpenIDIatTTL": NotRequired[str],
-        "OpenIDIssueURL": NotRequired[str],
-        "OpenIDProviderName": NotRequired[str],
+        "CognitoUserPoolId": str,
+        "Description": str,
+        "ExpirationTime": float,
+        "OpenIDAuthTTL": str,
+        "OpenIDClientId": str,
+        "OpenIDIatTTL": str,
+        "OpenIDIssueURL": str,
+        "OpenIDProviderName": str,
     },
+    total=False,
 )
 
 BackendAPIAuthTypeTypeDef = TypedDict(
     "BackendAPIAuthTypeTypeDef",
     {
-        "Mode": NotRequired[ModeType],
-        "Settings": NotRequired["BackendAPIAppSyncAuthSettingsTypeDef"],
+        "Mode": ModeType,
+        "Settings": "BackendAPIAppSyncAuthSettingsTypeDef",
     },
+    total=False,
 )
 
 BackendAPIConflictResolutionTypeDef = TypedDict(
     "BackendAPIConflictResolutionTypeDef",
     {
-        "ResolutionStrategy": NotRequired[ResolutionStrategyType],
+        "ResolutionStrategy": ResolutionStrategyType,
     },
+    total=False,
 )
 
 BackendAPIResourceConfigTypeDef = TypedDict(
     "BackendAPIResourceConfigTypeDef",
     {
-        "AdditionalAuthTypes": NotRequired[Sequence["BackendAPIAuthTypeTypeDef"]],
-        "ApiName": NotRequired[str],
-        "ConflictResolution": NotRequired["BackendAPIConflictResolutionTypeDef"],
-        "DefaultAuthType": NotRequired["BackendAPIAuthTypeTypeDef"],
-        "Service": NotRequired[str],
-        "TransformSchema": NotRequired[str],
+        "AdditionalAuthTypes": Sequence["BackendAPIAuthTypeTypeDef"],
+        "ApiName": str,
+        "ConflictResolution": "BackendAPIConflictResolutionTypeDef",
+        "DefaultAuthType": "BackendAPIAuthTypeTypeDef",
+        "Service": str,
+        "TransformSchema": str,
     },
+    total=False,
 )
 
 BackendAuthAppleProviderConfigTypeDef = TypedDict(
     "BackendAuthAppleProviderConfigTypeDef",
     {
-        "ClientId": NotRequired[str],
-        "KeyId": NotRequired[str],
-        "PrivateKey": NotRequired[str],
-        "TeamId": NotRequired[str],
+        "ClientId": str,
+        "KeyId": str,
+        "PrivateKey": str,
+        "TeamId": str,
     },
+    total=False,
 )
 
 BackendAuthSocialProviderConfigTypeDef = TypedDict(
     "BackendAuthSocialProviderConfigTypeDef",
     {
-        "ClientId": NotRequired[str],
-        "ClientSecret": NotRequired[str],
+        "ClientId": str,
+        "ClientSecret": str,
     },
+    total=False,
 )
 
-BackendJobRespObjTypeDef = TypedDict(
-    "BackendJobRespObjTypeDef",
+_RequiredBackendJobRespObjTypeDef = TypedDict(
+    "_RequiredBackendJobRespObjTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
-        "CreateTime": NotRequired[str],
-        "Error": NotRequired[str],
-        "JobId": NotRequired[str],
-        "Operation": NotRequired[str],
-        "Status": NotRequired[str],
-        "UpdateTime": NotRequired[str],
     },
 )
+_OptionalBackendJobRespObjTypeDef = TypedDict(
+    "_OptionalBackendJobRespObjTypeDef",
+    {
+        "CreateTime": str,
+        "Error": str,
+        "JobId": str,
+        "Operation": str,
+        "Status": str,
+        "UpdateTime": str,
+    },
+    total=False,
+)
 
-BackendStoragePermissionsTypeDef = TypedDict(
-    "BackendStoragePermissionsTypeDef",
+
+class BackendJobRespObjTypeDef(
+    _RequiredBackendJobRespObjTypeDef, _OptionalBackendJobRespObjTypeDef
+):
+    pass
+
+
+_RequiredBackendStoragePermissionsTypeDef = TypedDict(
+    "_RequiredBackendStoragePermissionsTypeDef",
     {
         "Authenticated": Sequence[AuthenticatedElementType],
-        "UnAuthenticated": NotRequired[Sequence[UnAuthenticatedElementType]],
     },
 )
+_OptionalBackendStoragePermissionsTypeDef = TypedDict(
+    "_OptionalBackendStoragePermissionsTypeDef",
+    {
+        "UnAuthenticated": Sequence[UnAuthenticatedElementType],
+    },
+    total=False,
+)
+
+
+class BackendStoragePermissionsTypeDef(
+    _RequiredBackendStoragePermissionsTypeDef, _OptionalBackendStoragePermissionsTypeDef
+):
+    pass
+
 
 CloneBackendRequestRequestTypeDef = TypedDict(
     "CloneBackendRequestRequestTypeDef",
@@ -269,14 +300,28 @@ CreateBackendAPIResponseTypeDef = TypedDict(
     },
 )
 
-CreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
-    "CreateBackendAuthForgotPasswordConfigTypeDef",
+_RequiredCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthForgotPasswordConfigTypeDef",
     {
         "DeliveryMethod": DeliveryMethodType,
-        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
-        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
     },
 )
+_OptionalCreateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthForgotPasswordConfigTypeDef",
+    {
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthForgotPasswordConfigTypeDef(
+    _RequiredCreateBackendAuthForgotPasswordConfigTypeDef,
+    _OptionalCreateBackendAuthForgotPasswordConfigTypeDef,
+):
+    pass
+
 
 CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
     "CreateBackendAuthIdentityPoolConfigTypeDef",
@@ -286,33 +331,73 @@ CreateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
     },
 )
 
-CreateBackendAuthMFAConfigTypeDef = TypedDict(
-    "CreateBackendAuthMFAConfigTypeDef",
+_RequiredCreateBackendAuthMFAConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthMFAConfigTypeDef",
     {
         "MFAMode": MFAModeType,
-        "Settings": NotRequired["SettingsTypeDef"],
     },
 )
+_OptionalCreateBackendAuthMFAConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthMFAConfigTypeDef",
+    {
+        "Settings": "SettingsTypeDef",
+    },
+    total=False,
+)
 
-CreateBackendAuthOAuthConfigTypeDef = TypedDict(
-    "CreateBackendAuthOAuthConfigTypeDef",
+
+class CreateBackendAuthMFAConfigTypeDef(
+    _RequiredCreateBackendAuthMFAConfigTypeDef, _OptionalCreateBackendAuthMFAConfigTypeDef
+):
+    pass
+
+
+_RequiredCreateBackendAuthOAuthConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthOAuthConfigTypeDef",
     {
         "OAuthGrantType": OAuthGrantTypeType,
         "OAuthScopes": Sequence[OAuthScopesElementType],
         "RedirectSignInURIs": Sequence[str],
         "RedirectSignOutURIs": Sequence[str],
-        "DomainPrefix": NotRequired[str],
-        "SocialProviderSettings": NotRequired["SocialProviderSettingsTypeDef"],
     },
 )
+_OptionalCreateBackendAuthOAuthConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthOAuthConfigTypeDef",
+    {
+        "DomainPrefix": str,
+        "SocialProviderSettings": "SocialProviderSettingsTypeDef",
+    },
+    total=False,
+)
 
-CreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
-    "CreateBackendAuthPasswordPolicyConfigTypeDef",
+
+class CreateBackendAuthOAuthConfigTypeDef(
+    _RequiredCreateBackendAuthOAuthConfigTypeDef, _OptionalCreateBackendAuthOAuthConfigTypeDef
+):
+    pass
+
+
+_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthPasswordPolicyConfigTypeDef",
     {
         "MinimumLength": float,
-        "AdditionalConstraints": NotRequired[Sequence[AdditionalConstraintsElementType]],
     },
 )
+_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthPasswordPolicyConfigTypeDef",
+    {
+        "AdditionalConstraints": Sequence[AdditionalConstraintsElementType],
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthPasswordPolicyConfigTypeDef(
+    _RequiredCreateBackendAuthPasswordPolicyConfigTypeDef,
+    _OptionalCreateBackendAuthPasswordPolicyConfigTypeDef,
+):
+    pass
+
 
 CreateBackendAuthRequestRequestTypeDef = TypedDict(
     "CreateBackendAuthRequestRequestTypeDef",
@@ -324,15 +409,28 @@ CreateBackendAuthRequestRequestTypeDef = TypedDict(
     },
 )
 
-CreateBackendAuthResourceConfigTypeDef = TypedDict(
-    "CreateBackendAuthResourceConfigTypeDef",
+_RequiredCreateBackendAuthResourceConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthResourceConfigTypeDef",
     {
         "AuthResources": AuthResourcesType,
         "Service": Literal["COGNITO"],
         "UserPoolConfigs": "CreateBackendAuthUserPoolConfigTypeDef",
-        "IdentityPoolConfigs": NotRequired["CreateBackendAuthIdentityPoolConfigTypeDef"],
     },
 )
+_OptionalCreateBackendAuthResourceConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthResourceConfigTypeDef",
+    {
+        "IdentityPoolConfigs": "CreateBackendAuthIdentityPoolConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateBackendAuthResourceConfigTypeDef(
+    _RequiredCreateBackendAuthResourceConfigTypeDef, _OptionalCreateBackendAuthResourceConfigTypeDef
+):
+    pass
+
 
 CreateBackendAuthResponseTypeDef = TypedDict(
     "CreateBackendAuthResponseTypeDef",
@@ -347,36 +445,77 @@ CreateBackendAuthResponseTypeDef = TypedDict(
     },
 )
 
-CreateBackendAuthUserPoolConfigTypeDef = TypedDict(
-    "CreateBackendAuthUserPoolConfigTypeDef",
+_RequiredCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthUserPoolConfigTypeDef",
     {
         "RequiredSignUpAttributes": Sequence[RequiredSignUpAttributesElementType],
         "SignInMethod": SignInMethodType,
         "UserPoolName": str,
-        "ForgotPassword": NotRequired["CreateBackendAuthForgotPasswordConfigTypeDef"],
-        "Mfa": NotRequired["CreateBackendAuthMFAConfigTypeDef"],
-        "OAuth": NotRequired["CreateBackendAuthOAuthConfigTypeDef"],
-        "PasswordPolicy": NotRequired["CreateBackendAuthPasswordPolicyConfigTypeDef"],
-        "VerificationMessage": NotRequired["CreateBackendAuthVerificationMessageConfigTypeDef"],
     },
 )
+_OptionalCreateBackendAuthUserPoolConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthUserPoolConfigTypeDef",
+    {
+        "ForgotPassword": "CreateBackendAuthForgotPasswordConfigTypeDef",
+        "Mfa": "CreateBackendAuthMFAConfigTypeDef",
+        "OAuth": "CreateBackendAuthOAuthConfigTypeDef",
+        "PasswordPolicy": "CreateBackendAuthPasswordPolicyConfigTypeDef",
+        "VerificationMessage": "CreateBackendAuthVerificationMessageConfigTypeDef",
+    },
+    total=False,
+)
 
-CreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
-    "CreateBackendAuthVerificationMessageConfigTypeDef",
+
+class CreateBackendAuthUserPoolConfigTypeDef(
+    _RequiredCreateBackendAuthUserPoolConfigTypeDef, _OptionalCreateBackendAuthUserPoolConfigTypeDef
+):
+    pass
+
+
+_RequiredCreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendAuthVerificationMessageConfigTypeDef",
     {
         "DeliveryMethod": DeliveryMethodType,
-        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
-        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
     },
 )
+_OptionalCreateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendAuthVerificationMessageConfigTypeDef",
+    {
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
+    },
+    total=False,
+)
 
-CreateBackendConfigRequestRequestTypeDef = TypedDict(
-    "CreateBackendConfigRequestRequestTypeDef",
+
+class CreateBackendAuthVerificationMessageConfigTypeDef(
+    _RequiredCreateBackendAuthVerificationMessageConfigTypeDef,
+    _OptionalCreateBackendAuthVerificationMessageConfigTypeDef,
+):
+    pass
+
+
+_RequiredCreateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateBackendConfigRequestRequestTypeDef",
     {
         "AppId": str,
-        "BackendManagerAppId": NotRequired[str],
     },
 )
+_OptionalCreateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateBackendConfigRequestRequestTypeDef",
+    {
+        "BackendManagerAppId": str,
+    },
+    total=False,
+)
+
+
+class CreateBackendConfigRequestRequestTypeDef(
+    _RequiredCreateBackendConfigRequestRequestTypeDef,
+    _OptionalCreateBackendConfigRequestRequestTypeDef,
+):
+    pass
+
 
 CreateBackendConfigResponseTypeDef = TypedDict(
     "CreateBackendConfigResponseTypeDef",
@@ -389,16 +528,29 @@ CreateBackendConfigResponseTypeDef = TypedDict(
     },
 )
 
-CreateBackendRequestRequestTypeDef = TypedDict(
-    "CreateBackendRequestRequestTypeDef",
+_RequiredCreateBackendRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateBackendRequestRequestTypeDef",
     {
         "AppId": str,
         "AppName": str,
         "BackendEnvironmentName": str,
-        "ResourceConfig": NotRequired[Mapping[str, Any]],
-        "ResourceName": NotRequired[str],
     },
 )
+_OptionalCreateBackendRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateBackendRequestRequestTypeDef",
+    {
+        "ResourceConfig": Mapping[str, Any],
+        "ResourceName": str,
+    },
+    total=False,
+)
+
+
+class CreateBackendRequestRequestTypeDef(
+    _RequiredCreateBackendRequestRequestTypeDef, _OptionalCreateBackendRequestRequestTypeDef
+):
+    pass
+
 
 CreateBackendResponseTypeDef = TypedDict(
     "CreateBackendResponseTypeDef",
@@ -423,14 +575,28 @@ CreateBackendStorageRequestRequestTypeDef = TypedDict(
     },
 )
 
-CreateBackendStorageResourceConfigTypeDef = TypedDict(
-    "CreateBackendStorageResourceConfigTypeDef",
+_RequiredCreateBackendStorageResourceConfigTypeDef = TypedDict(
+    "_RequiredCreateBackendStorageResourceConfigTypeDef",
     {
         "Permissions": "BackendStoragePermissionsTypeDef",
         "ServiceName": Literal["S3"],
-        "BucketName": NotRequired[str],
     },
 )
+_OptionalCreateBackendStorageResourceConfigTypeDef = TypedDict(
+    "_OptionalCreateBackendStorageResourceConfigTypeDef",
+    {
+        "BucketName": str,
+    },
+    total=False,
+)
+
+
+class CreateBackendStorageResourceConfigTypeDef(
+    _RequiredCreateBackendStorageResourceConfigTypeDef,
+    _OptionalCreateBackendStorageResourceConfigTypeDef,
+):
+    pass
+
 
 CreateBackendStorageResponseTypeDef = TypedDict(
     "CreateBackendStorageResponseTypeDef",
@@ -461,15 +627,28 @@ CreateTokenResponseTypeDef = TypedDict(
     },
 )
 
-DeleteBackendAPIRequestRequestTypeDef = TypedDict(
-    "DeleteBackendAPIRequestRequestTypeDef",
+_RequiredDeleteBackendAPIRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
-        "ResourceConfig": NotRequired["BackendAPIResourceConfigTypeDef"],
     },
 )
+_OptionalDeleteBackendAPIRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteBackendAPIRequestRequestTypeDef",
+    {
+        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class DeleteBackendAPIRequestRequestTypeDef(
+    _RequiredDeleteBackendAPIRequestRequestTypeDef, _OptionalDeleteBackendAPIRequestRequestTypeDef
+):
+    pass
+
 
 DeleteBackendAPIResponseTypeDef = TypedDict(
     "DeleteBackendAPIResponseTypeDef",
@@ -567,9 +746,10 @@ DeleteTokenResponseTypeDef = TypedDict(
 EmailSettingsTypeDef = TypedDict(
     "EmailSettingsTypeDef",
     {
-        "EmailMessage": NotRequired[str],
-        "EmailSubject": NotRequired[str],
+        "EmailMessage": str,
+        "EmailSubject": str,
     },
+    total=False,
 )
 
 GenerateBackendAPIModelsRequestRequestTypeDef = TypedDict(
@@ -612,15 +792,28 @@ GetBackendAPIModelsResponseTypeDef = TypedDict(
     },
 )
 
-GetBackendAPIRequestRequestTypeDef = TypedDict(
-    "GetBackendAPIRequestRequestTypeDef",
+_RequiredGetBackendAPIRequestRequestTypeDef = TypedDict(
+    "_RequiredGetBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
-        "ResourceConfig": NotRequired["BackendAPIResourceConfigTypeDef"],
     },
 )
+_OptionalGetBackendAPIRequestRequestTypeDef = TypedDict(
+    "_OptionalGetBackendAPIRequestRequestTypeDef",
+    {
+        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class GetBackendAPIRequestRequestTypeDef(
+    _RequiredGetBackendAPIRequestRequestTypeDef, _OptionalGetBackendAPIRequestRequestTypeDef
+):
+    pass
+
 
 GetBackendAPIResponseTypeDef = TypedDict(
     "GetBackendAPIResponseTypeDef",
@@ -679,13 +872,26 @@ GetBackendJobResponseTypeDef = TypedDict(
     },
 )
 
-GetBackendRequestRequestTypeDef = TypedDict(
-    "GetBackendRequestRequestTypeDef",
+_RequiredGetBackendRequestRequestTypeDef = TypedDict(
+    "_RequiredGetBackendRequestRequestTypeDef",
     {
         "AppId": str,
-        "BackendEnvironmentName": NotRequired[str],
     },
 )
+_OptionalGetBackendRequestRequestTypeDef = TypedDict(
+    "_OptionalGetBackendRequestRequestTypeDef",
+    {
+        "BackendEnvironmentName": str,
+    },
+    total=False,
+)
+
+
+class GetBackendRequestRequestTypeDef(
+    _RequiredGetBackendRequestRequestTypeDef, _OptionalGetBackendRequestRequestTypeDef
+):
+    pass
+
 
 GetBackendResponseTypeDef = TypedDict(
     "GetBackendResponseTypeDef",
@@ -710,15 +916,28 @@ GetBackendStorageRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetBackendStorageResourceConfigTypeDef = TypedDict(
-    "GetBackendStorageResourceConfigTypeDef",
+_RequiredGetBackendStorageResourceConfigTypeDef = TypedDict(
+    "_RequiredGetBackendStorageResourceConfigTypeDef",
     {
         "Imported": bool,
         "ServiceName": Literal["S3"],
-        "BucketName": NotRequired[str],
-        "Permissions": NotRequired["BackendStoragePermissionsTypeDef"],
     },
 )
+_OptionalGetBackendStorageResourceConfigTypeDef = TypedDict(
+    "_OptionalGetBackendStorageResourceConfigTypeDef",
+    {
+        "BucketName": str,
+        "Permissions": "BackendStoragePermissionsTypeDef",
+    },
+    total=False,
+)
+
+
+class GetBackendStorageResourceConfigTypeDef(
+    _RequiredGetBackendStorageResourceConfigTypeDef, _OptionalGetBackendStorageResourceConfigTypeDef
+):
+    pass
+
 
 GetBackendStorageResponseTypeDef = TypedDict(
     "GetBackendStorageResponseTypeDef",
@@ -750,17 +969,30 @@ GetTokenResponseTypeDef = TypedDict(
     },
 )
 
-ImportBackendAuthRequestRequestTypeDef = TypedDict(
-    "ImportBackendAuthRequestRequestTypeDef",
+_RequiredImportBackendAuthRequestRequestTypeDef = TypedDict(
+    "_RequiredImportBackendAuthRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "NativeClientId": str,
         "UserPoolId": str,
         "WebClientId": str,
-        "IdentityPoolId": NotRequired[str],
     },
 )
+_OptionalImportBackendAuthRequestRequestTypeDef = TypedDict(
+    "_OptionalImportBackendAuthRequestRequestTypeDef",
+    {
+        "IdentityPoolId": str,
+    },
+    total=False,
+)
+
+
+class ImportBackendAuthRequestRequestTypeDef(
+    _RequiredImportBackendAuthRequestRequestTypeDef, _OptionalImportBackendAuthRequestRequestTypeDef
+):
+    pass
+
 
 ImportBackendAuthResponseTypeDef = TypedDict(
     "ImportBackendAuthResponseTypeDef",
@@ -775,15 +1007,29 @@ ImportBackendAuthResponseTypeDef = TypedDict(
     },
 )
 
-ImportBackendStorageRequestRequestTypeDef = TypedDict(
-    "ImportBackendStorageRequestRequestTypeDef",
+_RequiredImportBackendStorageRequestRequestTypeDef = TypedDict(
+    "_RequiredImportBackendStorageRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ServiceName": Literal["S3"],
-        "BucketName": NotRequired[str],
     },
 )
+_OptionalImportBackendStorageRequestRequestTypeDef = TypedDict(
+    "_OptionalImportBackendStorageRequestRequestTypeDef",
+    {
+        "BucketName": str,
+    },
+    total=False,
+)
+
+
+class ImportBackendStorageRequestRequestTypeDef(
+    _RequiredImportBackendStorageRequestRequestTypeDef,
+    _OptionalImportBackendStorageRequestRequestTypeDef,
+):
+    pass
+
 
 ImportBackendStorageResponseTypeDef = TypedDict(
     "ImportBackendStorageResponseTypeDef",
@@ -796,18 +1042,57 @@ ImportBackendStorageResponseTypeDef = TypedDict(
     },
 )
 
-ListBackendJobsRequestRequestTypeDef = TypedDict(
-    "ListBackendJobsRequestRequestTypeDef",
+_RequiredListBackendJobsRequestListBackendJobsPaginateTypeDef = TypedDict(
+    "_RequiredListBackendJobsRequestListBackendJobsPaginateTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
-        "JobId": NotRequired[str],
-        "MaxResults": NotRequired[int],
-        "NextToken": NotRequired[str],
-        "Operation": NotRequired[str],
-        "Status": NotRequired[str],
     },
 )
+_OptionalListBackendJobsRequestListBackendJobsPaginateTypeDef = TypedDict(
+    "_OptionalListBackendJobsRequestListBackendJobsPaginateTypeDef",
+    {
+        "JobId": str,
+        "Operation": str,
+        "Status": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListBackendJobsRequestListBackendJobsPaginateTypeDef(
+    _RequiredListBackendJobsRequestListBackendJobsPaginateTypeDef,
+    _OptionalListBackendJobsRequestListBackendJobsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListBackendJobsRequestRequestTypeDef = TypedDict(
+    "_RequiredListBackendJobsRequestRequestTypeDef",
+    {
+        "AppId": str,
+        "BackendEnvironmentName": str,
+    },
+)
+_OptionalListBackendJobsRequestRequestTypeDef = TypedDict(
+    "_OptionalListBackendJobsRequestRequestTypeDef",
+    {
+        "JobId": str,
+        "MaxResults": int,
+        "NextToken": str,
+        "Operation": str,
+        "Status": str,
+    },
+    total=False,
+)
+
+
+class ListBackendJobsRequestRequestTypeDef(
+    _RequiredListBackendJobsRequestRequestTypeDef, _OptionalListBackendJobsRequestRequestTypeDef
+):
+    pass
+
 
 ListBackendJobsResponseTypeDef = TypedDict(
     "ListBackendJobsResponseTypeDef",
@@ -821,8 +1106,9 @@ ListBackendJobsResponseTypeDef = TypedDict(
 ListS3BucketsRequestRequestTypeDef = TypedDict(
     "ListS3BucketsRequestRequestTypeDef",
     {
-        "NextToken": NotRequired[str],
+        "NextToken": str,
     },
+    total=False,
 )
 
 ListS3BucketsResponseTypeDef = TypedDict(
@@ -837,29 +1123,44 @@ ListS3BucketsResponseTypeDef = TypedDict(
 LoginAuthConfigReqObjTypeDef = TypedDict(
     "LoginAuthConfigReqObjTypeDef",
     {
-        "AwsCognitoIdentityPoolId": NotRequired[str],
-        "AwsCognitoRegion": NotRequired[str],
-        "AwsUserPoolsId": NotRequired[str],
-        "AwsUserPoolsWebClientId": NotRequired[str],
+        "AwsCognitoIdentityPoolId": str,
+        "AwsCognitoRegion": str,
+        "AwsUserPoolsId": str,
+        "AwsUserPoolsWebClientId": str,
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
-RemoveAllBackendsRequestRequestTypeDef = TypedDict(
-    "RemoveAllBackendsRequestRequestTypeDef",
+_RequiredRemoveAllBackendsRequestRequestTypeDef = TypedDict(
+    "_RequiredRemoveAllBackendsRequestRequestTypeDef",
     {
         "AppId": str,
-        "CleanAmplifyApp": NotRequired[bool],
     },
 )
+_OptionalRemoveAllBackendsRequestRequestTypeDef = TypedDict(
+    "_OptionalRemoveAllBackendsRequestRequestTypeDef",
+    {
+        "CleanAmplifyApp": bool,
+    },
+    total=False,
+)
+
+
+class RemoveAllBackendsRequestRequestTypeDef(
+    _RequiredRemoveAllBackendsRequestRequestTypeDef, _OptionalRemoveAllBackendsRequestRequestTypeDef
+):
+    pass
+
 
 RemoveAllBackendsResponseTypeDef = TypedDict(
     "RemoveAllBackendsResponseTypeDef",
@@ -902,45 +1203,62 @@ ResponseMetadataTypeDef = TypedDict(
 S3BucketInfoTypeDef = TypedDict(
     "S3BucketInfoTypeDef",
     {
-        "CreationDate": NotRequired[str],
-        "Name": NotRequired[str],
+        "CreationDate": str,
+        "Name": str,
     },
+    total=False,
 )
 
 SettingsTypeDef = TypedDict(
     "SettingsTypeDef",
     {
-        "MfaTypes": NotRequired[Sequence[MfaTypesElementType]],
-        "SmsMessage": NotRequired[str],
+        "MfaTypes": Sequence[MfaTypesElementType],
+        "SmsMessage": str,
     },
+    total=False,
 )
 
 SmsSettingsTypeDef = TypedDict(
     "SmsSettingsTypeDef",
     {
-        "SmsMessage": NotRequired[str],
+        "SmsMessage": str,
     },
+    total=False,
 )
 
 SocialProviderSettingsTypeDef = TypedDict(
     "SocialProviderSettingsTypeDef",
     {
-        "Facebook": NotRequired["BackendAuthSocialProviderConfigTypeDef"],
-        "Google": NotRequired["BackendAuthSocialProviderConfigTypeDef"],
-        "LoginWithAmazon": NotRequired["BackendAuthSocialProviderConfigTypeDef"],
-        "SignInWithApple": NotRequired["BackendAuthAppleProviderConfigTypeDef"],
+        "Facebook": "BackendAuthSocialProviderConfigTypeDef",
+        "Google": "BackendAuthSocialProviderConfigTypeDef",
+        "LoginWithAmazon": "BackendAuthSocialProviderConfigTypeDef",
+        "SignInWithApple": "BackendAuthAppleProviderConfigTypeDef",
     },
+    total=False,
 )
 
-UpdateBackendAPIRequestRequestTypeDef = TypedDict(
-    "UpdateBackendAPIRequestRequestTypeDef",
+_RequiredUpdateBackendAPIRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendAPIRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "ResourceName": str,
-        "ResourceConfig": NotRequired["BackendAPIResourceConfigTypeDef"],
     },
 )
+_OptionalUpdateBackendAPIRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendAPIRequestRequestTypeDef",
+    {
+        "ResourceConfig": "BackendAPIResourceConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateBackendAPIRequestRequestTypeDef(
+    _RequiredUpdateBackendAPIRequestRequestTypeDef, _OptionalUpdateBackendAPIRequestRequestTypeDef
+):
+    pass
+
 
 UpdateBackendAPIResponseTypeDef = TypedDict(
     "UpdateBackendAPIResponseTypeDef",
@@ -958,45 +1276,50 @@ UpdateBackendAPIResponseTypeDef = TypedDict(
 UpdateBackendAuthForgotPasswordConfigTypeDef = TypedDict(
     "UpdateBackendAuthForgotPasswordConfigTypeDef",
     {
-        "DeliveryMethod": NotRequired[DeliveryMethodType],
-        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
-        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
+        "DeliveryMethod": DeliveryMethodType,
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
     },
+    total=False,
 )
 
 UpdateBackendAuthIdentityPoolConfigTypeDef = TypedDict(
     "UpdateBackendAuthIdentityPoolConfigTypeDef",
     {
-        "UnauthenticatedLogin": NotRequired[bool],
+        "UnauthenticatedLogin": bool,
     },
+    total=False,
 )
 
 UpdateBackendAuthMFAConfigTypeDef = TypedDict(
     "UpdateBackendAuthMFAConfigTypeDef",
     {
-        "MFAMode": NotRequired[MFAModeType],
-        "Settings": NotRequired["SettingsTypeDef"],
+        "MFAMode": MFAModeType,
+        "Settings": "SettingsTypeDef",
     },
+    total=False,
 )
 
 UpdateBackendAuthOAuthConfigTypeDef = TypedDict(
     "UpdateBackendAuthOAuthConfigTypeDef",
     {
-        "DomainPrefix": NotRequired[str],
-        "OAuthGrantType": NotRequired[OAuthGrantTypeType],
-        "OAuthScopes": NotRequired[Sequence[OAuthScopesElementType]],
-        "RedirectSignInURIs": NotRequired[Sequence[str]],
-        "RedirectSignOutURIs": NotRequired[Sequence[str]],
-        "SocialProviderSettings": NotRequired["SocialProviderSettingsTypeDef"],
+        "DomainPrefix": str,
+        "OAuthGrantType": OAuthGrantTypeType,
+        "OAuthScopes": Sequence[OAuthScopesElementType],
+        "RedirectSignInURIs": Sequence[str],
+        "RedirectSignOutURIs": Sequence[str],
+        "SocialProviderSettings": "SocialProviderSettingsTypeDef",
     },
+    total=False,
 )
 
 UpdateBackendAuthPasswordPolicyConfigTypeDef = TypedDict(
     "UpdateBackendAuthPasswordPolicyConfigTypeDef",
     {
-        "AdditionalConstraints": NotRequired[Sequence[AdditionalConstraintsElementType]],
-        "MinimumLength": NotRequired[float],
+        "AdditionalConstraints": Sequence[AdditionalConstraintsElementType],
+        "MinimumLength": float,
     },
+    total=False,
 )
 
 UpdateBackendAuthRequestRequestTypeDef = TypedDict(
@@ -1009,15 +1332,28 @@ UpdateBackendAuthRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateBackendAuthResourceConfigTypeDef = TypedDict(
-    "UpdateBackendAuthResourceConfigTypeDef",
+_RequiredUpdateBackendAuthResourceConfigTypeDef = TypedDict(
+    "_RequiredUpdateBackendAuthResourceConfigTypeDef",
     {
         "AuthResources": AuthResourcesType,
         "Service": Literal["COGNITO"],
         "UserPoolConfigs": "UpdateBackendAuthUserPoolConfigTypeDef",
-        "IdentityPoolConfigs": NotRequired["UpdateBackendAuthIdentityPoolConfigTypeDef"],
     },
 )
+_OptionalUpdateBackendAuthResourceConfigTypeDef = TypedDict(
+    "_OptionalUpdateBackendAuthResourceConfigTypeDef",
+    {
+        "IdentityPoolConfigs": "UpdateBackendAuthIdentityPoolConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateBackendAuthResourceConfigTypeDef(
+    _RequiredUpdateBackendAuthResourceConfigTypeDef, _OptionalUpdateBackendAuthResourceConfigTypeDef
+):
+    pass
+
 
 UpdateBackendAuthResponseTypeDef = TypedDict(
     "UpdateBackendAuthResponseTypeDef",
@@ -1035,30 +1371,59 @@ UpdateBackendAuthResponseTypeDef = TypedDict(
 UpdateBackendAuthUserPoolConfigTypeDef = TypedDict(
     "UpdateBackendAuthUserPoolConfigTypeDef",
     {
-        "ForgotPassword": NotRequired["UpdateBackendAuthForgotPasswordConfigTypeDef"],
-        "Mfa": NotRequired["UpdateBackendAuthMFAConfigTypeDef"],
-        "OAuth": NotRequired["UpdateBackendAuthOAuthConfigTypeDef"],
-        "PasswordPolicy": NotRequired["UpdateBackendAuthPasswordPolicyConfigTypeDef"],
-        "VerificationMessage": NotRequired["UpdateBackendAuthVerificationMessageConfigTypeDef"],
+        "ForgotPassword": "UpdateBackendAuthForgotPasswordConfigTypeDef",
+        "Mfa": "UpdateBackendAuthMFAConfigTypeDef",
+        "OAuth": "UpdateBackendAuthOAuthConfigTypeDef",
+        "PasswordPolicy": "UpdateBackendAuthPasswordPolicyConfigTypeDef",
+        "VerificationMessage": "UpdateBackendAuthVerificationMessageConfigTypeDef",
     },
+    total=False,
 )
 
-UpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
-    "UpdateBackendAuthVerificationMessageConfigTypeDef",
+_RequiredUpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_RequiredUpdateBackendAuthVerificationMessageConfigTypeDef",
     {
         "DeliveryMethod": DeliveryMethodType,
-        "EmailSettings": NotRequired["EmailSettingsTypeDef"],
-        "SmsSettings": NotRequired["SmsSettingsTypeDef"],
     },
 )
+_OptionalUpdateBackendAuthVerificationMessageConfigTypeDef = TypedDict(
+    "_OptionalUpdateBackendAuthVerificationMessageConfigTypeDef",
+    {
+        "EmailSettings": "EmailSettingsTypeDef",
+        "SmsSettings": "SmsSettingsTypeDef",
+    },
+    total=False,
+)
 
-UpdateBackendConfigRequestRequestTypeDef = TypedDict(
-    "UpdateBackendConfigRequestRequestTypeDef",
+
+class UpdateBackendAuthVerificationMessageConfigTypeDef(
+    _RequiredUpdateBackendAuthVerificationMessageConfigTypeDef,
+    _OptionalUpdateBackendAuthVerificationMessageConfigTypeDef,
+):
+    pass
+
+
+_RequiredUpdateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendConfigRequestRequestTypeDef",
     {
         "AppId": str,
-        "LoginAuthConfig": NotRequired["LoginAuthConfigReqObjTypeDef"],
     },
 )
+_OptionalUpdateBackendConfigRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendConfigRequestRequestTypeDef",
+    {
+        "LoginAuthConfig": "LoginAuthConfigReqObjTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateBackendConfigRequestRequestTypeDef(
+    _RequiredUpdateBackendConfigRequestRequestTypeDef,
+    _OptionalUpdateBackendConfigRequestRequestTypeDef,
+):
+    pass
+
 
 UpdateBackendConfigResponseTypeDef = TypedDict(
     "UpdateBackendConfigResponseTypeDef",
@@ -1071,16 +1436,29 @@ UpdateBackendConfigResponseTypeDef = TypedDict(
     },
 )
 
-UpdateBackendJobRequestRequestTypeDef = TypedDict(
-    "UpdateBackendJobRequestRequestTypeDef",
+_RequiredUpdateBackendJobRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateBackendJobRequestRequestTypeDef",
     {
         "AppId": str,
         "BackendEnvironmentName": str,
         "JobId": str,
-        "Operation": NotRequired[str],
-        "Status": NotRequired[str],
     },
 )
+_OptionalUpdateBackendJobRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateBackendJobRequestRequestTypeDef",
+    {
+        "Operation": str,
+        "Status": str,
+    },
+    total=False,
+)
+
+
+class UpdateBackendJobRequestRequestTypeDef(
+    _RequiredUpdateBackendJobRequestRequestTypeDef, _OptionalUpdateBackendJobRequestRequestTypeDef
+):
+    pass
+
 
 UpdateBackendJobResponseTypeDef = TypedDict(
     "UpdateBackendJobResponseTypeDef",
